#version 430 core

struct Material {
    float ambient;
    float diffuse;
    float specular;
    float shininess;
}; 


struct DirLight {
    vec3 direction;
	vec3 color;
    float intensity;
};   


in vec2 TexCoords;
in vec3 normal;
in vec3 fragPos;

layout (location = 0) out vec4 FragColor;
layout (location = 1) out vec4 BloomColor;


uniform sampler2D texture_diffuse1;
uniform vec3 viewPos;

uniform Material material;

uniform DirLight dirLight;

vec3 CalcDirLight(DirLight light, Material material, vec3 normal, vec3 viewDir, vec3 objectColor);  



uniform bool dark;

uniform bool ball;

float levels = 8.0;


void main()
{
   vec3 color = texture( texture_diffuse1, TexCoords).rgb;

   vec3 normalizedNormal = normalize(normal);

   vec3 viewDir = normalize(viewPos - fragPos);

   vec3 colorOut = vec3(0.0);
  
   colorOut += CalcDirLight(dirLight, material, normalizedNormal, viewDir, color);
  
   if(!dark)
   {

        if(ball)
        {
         float brightness = dot(colorOut * color, vec3(0.3126, 0.3152, 0.3722));
         float brightness1 = dot(colorOut, vec3(0.2126, 0.7152, 0.0722));

         float level = floor(brightness1 * levels);

         brightness1 = level / levels;

        FragColor = vec4(brightness1 * color, 1);

        if(brightness > 1.0)
            BloomColor = vec4(colorOut * color, 1.0);
        else
            BloomColor = vec4(0.0, 0.0, 0.0, 1.0);
          
         }
         
        else
        {
        float brightness = dot(colorOut * color, vec3(0.3126, 0.3152, 0.3722));
   
        FragColor = vec4(colorOut * color, 1);

        if(brightness > 1.05)
            BloomColor = vec4(colorOut * color, 1.0);
        else
            BloomColor = vec4(0.0, 0.0, 0.0, 1.0);
        }

   } 
   
   else
   {
        float brightness = dot(colorOut * color, vec3(0.3126, 0.3152, 0.3722));

            if(brightness > 0.6)
        BloomColor = vec4(colorOut * color, 1.0);
            else
        BloomColor = vec4(0.0, 0.0, 0.0, 1.0);

        FragColor = vec4(colorOut * color, 1);
   }
   
}

vec3 CalcDirLight(DirLight light, Material material, vec3 normal, vec3 viewDir, vec3 objectColor){
    vec3 lightDir = normalize(-light.direction);

    float diff = max(dot(normal, lightDir), 0.0);

    vec3 reflectDir = reflect(-lightDir, normal);

    float spec = pow(max(dot(viewDir, reflectDir), 0.0), material.shininess);

    vec3 ambient = material.ambient * light.color;
    vec3 diffuse = material.diffuse * light.color * diff;
    vec3 specular = material.specular * light.color * spec;

    return (((ambient + diffuse) * objectColor + specular) * light.intensity);
}